==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/SourceCode.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Represents a source file.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.441Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.SourceCode")
public class SourceCode extends io.github.cdklabs.projen.Component {

    protected SourceCode(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected SourceCode(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param filePath This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public SourceCode(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull java.lang.String filePath, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.SourceCodeOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(filePath, "filePath is required"), options });
    }

    /**
     * @param project This parameter is required.
     * @param filePath This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public SourceCode(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull java.lang.String filePath) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(filePath, "filePath is required") });
    }

    /**
     * (experimental) Decreases the indentation level and closes a code block.
     * <p>
     * @param code The code after the block is closed (e.g. `}`).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void close(final @org.jetbrains.annotations.Nullable java.lang.String code) {
        software.amazon.jsii.Kernel.call(this, "close", software.amazon.jsii.NativeType.VOID, new Object[] { code });
    }

    /**
     * (experimental) Decreases the indentation level and closes a code block.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void close() {
        software.amazon.jsii.Kernel.call(this, "close", software.amazon.jsii.NativeType.VOID);
    }

    /**
     * (experimental) Emit a line of code.
     * <p>
     * @param code The contents, if not specified, just adds a newline.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void line(final @org.jetbrains.annotations.Nullable java.lang.String code) {
        software.amazon.jsii.Kernel.call(this, "line", software.amazon.jsii.NativeType.VOID, new Object[] { code });
    }

    /**
     * (experimental) Emit a line of code.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void line() {
        software.amazon.jsii.Kernel.call(this, "line", software.amazon.jsii.NativeType.VOID);
    }

    /**
     * (experimental) Opens a code block and increases the indentation level.
     * <p>
     * @param code The code before the block starts (e.g. `export class {`).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void open(final @org.jetbrains.annotations.Nullable java.lang.String code) {
        software.amazon.jsii.Kernel.call(this, "open", software.amazon.jsii.NativeType.VOID, new Object[] { code });
    }

    /**
     * (experimental) Opens a code block and increases the indentation level.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void open() {
        software.amazon.jsii.Kernel.call(this, "open", software.amazon.jsii.NativeType.VOID);
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.SourceCode}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.SourceCode> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         * @param filePath This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project, final java.lang.String filePath) {
            return new Builder(project, filePath);
        }

        private final io.github.cdklabs.projen.Project project;
        private final java.lang.String filePath;
        private io.github.cdklabs.projen.SourceCodeOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project, final java.lang.String filePath) {
            this.project = project;
            this.filePath = filePath;
        }

        /**
         * (experimental) Indentation size.
         * <p>
         * Default: 2
         * <p>
         * @return {@code this}
         * @param indent Indentation size. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder indent(final java.lang.Number indent) {
            this.options().indent(indent);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.SourceCode}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.SourceCode build() {
            return new io.github.cdklabs.projen.SourceCode(
                this.project,
                this.filePath,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.SourceCodeOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.SourceCodeOptions.Builder();
            }
            return this.options;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/SourceCode.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Represents a source file.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.151Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.SourceCode")
public class SourceCode extends io.github.cdklabs.projen.Component {

    protected SourceCode(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected SourceCode(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param filePath This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public SourceCode(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull java.lang.String filePath, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.SourceCodeOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(filePath, "filePath is required"), options });
    }

    /**
     * @param project This parameter is required.
     * @param filePath This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public SourceCode(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull java.lang.String filePath) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(filePath, "filePath is required") });
    }

    /**
     * (experimental) Decreases the indentation level and closes a code block.
     * <p>
     * @param code The code after the block is closed (e.g. <code>}</code>).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void close(final @org.jetbrains.annotations.Nullable java.lang.String code) {
        software.amazon.jsii.Kernel.call(this, "close", software.amazon.jsii.NativeType.VOID, new Object[] { code });
    }

    /**
     * (experimental) Decreases the indentation level and closes a code block.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void close() {
        software.amazon.jsii.Kernel.call(this, "close", software.amazon.jsii.NativeType.VOID);
    }

    /**
     * (experimental) Emit a line of code.
     * <p>
     * @param code The contents, if not specified, just adds a newline.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void line(final @org.jetbrains.annotations.Nullable java.lang.String code) {
        software.amazon.jsii.Kernel.call(this, "line", software.amazon.jsii.NativeType.VOID, new Object[] { code });
    }

    /**
     * (experimental) Emit a line of code.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void line() {
        software.amazon.jsii.Kernel.call(this, "line", software.amazon.jsii.NativeType.VOID);
    }

    /**
     * (experimental) Opens a code block and increases the indentation level.
     * <p>
     * @param code The code before the block starts (e.g. <code>export class {</code>).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void open(final @org.jetbrains.annotations.Nullable java.lang.String code) {
        software.amazon.jsii.Kernel.call(this, "open", software.amazon.jsii.NativeType.VOID, new Object[] { code });
    }

    /**
     * (experimental) Opens a code block and increases the indentation level.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void open() {
        software.amazon.jsii.Kernel.call(this, "open", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getFilePath() {
        return software.amazon.jsii.Kernel.get(this, "filePath", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.Nullable java.lang.String getMarker() {
        return software.amazon.jsii.Kernel.get(this, "marker", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.SourceCode}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.SourceCode> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         * @param filePath This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project, final java.lang.String filePath) {
            return new Builder(project, filePath);
        }

        private final io.github.cdklabs.projen.Project project;
        private final java.lang.String filePath;
        private io.github.cdklabs.projen.SourceCodeOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project, final java.lang.String filePath) {
            this.project = project;
            this.filePath = filePath;
        }

        /**
         * (experimental) Indentation size.
         * <p>
         * Default: 2
         * <p>
         * @return {@code this}
         * @param indent Indentation size. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder indent(final java.lang.Number indent) {
            this.options().indent(indent);
            return this;
        }

        /**
         * (experimental) Whether the generated file should be readonly.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param readonly Whether the generated file should be readonly. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder readonly(final java.lang.Boolean readonly) {
            this.options().readonly(readonly);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.SourceCode}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.SourceCode build() {
            return new io.github.cdklabs.projen.SourceCode(
                this.project,
                this.filePath,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.SourceCodeOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.SourceCodeOptions.Builder();
            }
            return this.options;
        }
    }
}
